/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.sensor.fritzmeier;

/**
 *  enum for defining fields in the fritzmeier files
 *  contains 'start' 'end' positions, mandatory length, mandatory and dat type
 *  the mandatory lenght is introduced due to the fact that fields could be negative and have a extra minus "-" character
 *  @author Gerben Feenstra
 */


public enum FritzmeierFileDescription {
        /* Latitude of measured cropcircle coordinate */
        LATITUDE(0,12,true,java.lang.Double.class), 
        
        /* Longitude of measured cropcircle coordinate */
	LONGITUDE(1,12,true,java.lang.Double.class), 
        
        DATE(2, 8, true, java.util.Date.class),
        
        /* Time */
	TIME(3,8,true,java.util.Date.class),  
          
        /* Course */
	HEAD(4,1,true,java.lang.Double.class),
                
        /* Latitude of measured cropcircle coordinate */
        LAT_ORG(5,12,true,java.lang.Double.class), 
        
        /* Longitude of measured cropcircle coordinate */
	LON_ORG(6,12,true,java.lang.Double.class), 
        
        /* Height of the sensor in m */
	ALTITUDE(7,4,true,java.lang.Double.class),
                    
        /* Speed of vehicle at the moment this coordinate is measured. m/s */
	SPEED(8,3,true,java.lang.Double.class),
        
        /*  */
	FIXTYPE(9,1,true,java.lang.Integer.class), //1 4
        
        /* in nm */
        IRMI(10, 6, true, java.lang.Double.class),
        
        /* Biomassa en stikstof */
        TCARI(11, 5, true, java.lang.Double.class),
        
        /* Biomassa en stikstof */
        OSAVI(12, 5, true, java.lang.Double.class),
        
        /* */
        TC_OS(13, 5, true, java.lang.Double.class),
        
        /* Biomassa */
        WDVI(14, 5, true, java.lang.Double.class),
        
        /* */
        NDRE(15, 5, true, java.lang.Double.class);
        
	private final int position;
        private final int mandatoryLength;
	private final boolean mandatory;
	private final static String delimiter = ";";
        private final Class theClass;
	
	private FritzmeierFileDescription(int position, int mandatoryLength, boolean mandatory, Class theClass ){
		this.position = position;
		this.mandatory = mandatory;
                this.mandatoryLength = mandatoryLength;
                this.theClass = theClass;
	}
	
	public static String getDelimiter() {
		return delimiter;
	}

	public int getPosition() {
		return position;
	}

	public boolean isMandatory() {
		return mandatory;
	}

        public int getMandatoryLength() {
            return mandatoryLength;
        }

        public Class getTheClass() {
            return theClass;
        }	
}
