/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.sensor.fritzmeier;

import java.io.Serializable;
import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.util.Date;
import nl.cloudfarming.client.model.SensorObservation;

/**
 *
 * @author Arjan Loermans
 */
public class FritzmeierSensorData extends SensorObservation implements Serializable {

    public static final String Q_FIND_ALL_FRITZMEIER_SENSORDATA = "findAllFritzMeierSensorData";
    private static final String dateFormat = "dd.MM.yy";
    private static final String timeFormat = "HH:mm:ss";
    private int fixType;
    private Double altitude;
    private Date ddate; // date is a reserved word
    private Double latitudeOriginal;
    private Double longitudeOriginal;
    private Double irmi;
    private Double tcari;
    private Double osavi;
    private Double tcOs;
    private Double ndre;
    
    public String getDdateStr() {
        return new SimpleDateFormat(dateFormat).format(this.getDdate());
    }

    public void setDdateStr(String value) throws ParseException {
        this.setDdate(
                new SimpleDateFormat(dateFormat).parse(value));
    }

    public String getUtcTimeStr() {
        return new SimpleDateFormat(timeFormat).format(this.getUtcTime());
    }

    public void setUtcTimeStr(String value) throws ParseException {
        this.setUtcTime(
                new SimpleDateFormat(timeFormat).parse(value));
    }

    public Double getAltitude() {
        return altitude;
    }

    public void setAltitude(Double altitude) {
        this.altitude = altitude;
    }

    public Date getDdate() {
        return ddate;
    }

    public void setDdate(Date ddate) {
        this.ddate = ddate;
    }

    public int getFixType() {
        return fixType;
    }

    public void setFixType(int fixType) {
        this.fixType = fixType;
    }

    public Double getIrmi() {
        return irmi;
    }

    public void setIrmi(Double irmi) {
        this.irmi = irmi;
    }

    public Double getLatitudeOriginal() {
        return latitudeOriginal;
    }

    public void setLatitudeOriginal(Double latitudeOriginal) {
        this.latitudeOriginal = latitudeOriginal;
    }

    public Double getLongitudeOriginal() {
        return longitudeOriginal;
    }

    public void setLongitudeOriginal(Double longitudeOriginal) {
        this.longitudeOriginal = longitudeOriginal;
    }

    public Double getNdre() {
        return ndre;
    }

    public void setNdre(Double ndre) {
        this.ndre = ndre;
    }

    public Double getOsavi() {
        return osavi;
    }

    public void setOsavi(Double osavi) {
        this.osavi = osavi;
    }

    public Double getTcOs() {
        return tcOs;
    }

    public void setTcOs(Double tcOs) {
        this.tcOs = tcOs;
    }

    public Double getTcari() {
        return tcari;
    }

    public void setTcari(Double tcari) {
        this.tcari = tcari;
    }

    @Override
    public boolean equals(Object obj) {
        if (obj == null) {
            return false;
        }
        if (getClass() != obj.getClass()) {
            return false;
        }
        final FritzmeierSensorData other = (FritzmeierSensorData) obj;
        if (this.fixType != other.fixType) {
            return false;
        }
        if (this.altitude != other.altitude && (this.altitude == null || !this.altitude.equals(other.altitude))) {
            return false;
        }
        if (this.ddate != other.ddate && (this.ddate == null || !this.ddate.equals(other.ddate))) {
            return false;
        }
        if (this.latitudeOriginal != other.latitudeOriginal && (this.latitudeOriginal == null || !this.latitudeOriginal.equals(other.latitudeOriginal))) {
            return false;
        }
        if (this.longitudeOriginal != other.longitudeOriginal && (this.longitudeOriginal == null || !this.longitudeOriginal.equals(other.longitudeOriginal))) {
            return false;
        }
        if (this.irmi != other.irmi && (this.irmi == null || !this.irmi.equals(other.irmi))) {
            return false;
        }
        if (this.tcari != other.tcari && (this.tcari == null || !this.tcari.equals(other.tcari))) {
            return false;
        }
        if (this.osavi != other.osavi && (this.osavi == null || !this.osavi.equals(other.osavi))) {
            return false;
        }
        if (this.tcOs != other.tcOs && (this.tcOs == null || !this.tcOs.equals(other.tcOs))) {
            return false;
        }
        if (this.ndre != other.ndre && (this.ndre == null || !this.ndre.equals(other.ndre))) {
            return false;
        }
        return super.equals(obj);
    }

    // Fritzmeier sensor files have wdvi values in the range of 0 .. 1000. Devide by 1000 to normalize to a range of 0 .. 1
    @Override
    public Double getWdvi() {
        return super.getWdvi() / 1000;
    }

    @Override
    public int hashCode() {
        int hash = super.hashCode();
        hash = 47 * hash + this.fixType;
        hash = 47 * hash + (this.altitude != null ? this.altitude.hashCode() : 0);
        hash = 47 * hash + (this.ddate != null ? this.ddate.hashCode() : 0);
        hash = 47 * hash + (this.latitudeOriginal != null ? this.latitudeOriginal.hashCode() : 0);
        hash = 47 * hash + (this.longitudeOriginal != null ? this.longitudeOriginal.hashCode() : 0);
        hash = 47 * hash + (this.irmi != null ? this.irmi.hashCode() : 0);
        hash = 47 * hash + (this.tcari != null ? this.tcari.hashCode() : 0);
        hash = 47 * hash + (this.osavi != null ? this.osavi.hashCode() : 0);
        hash = 47 * hash + (this.tcOs != null ? this.tcOs.hashCode() : 0);
        hash = 47 * hash + (this.ndre != null ? this.ndre.hashCode() : 0);
        return hash;
    }
}
